@@ -1,22 +1,8 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2008-2013  Intel Corporation
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2008-2013  Intel Corporation. All rights reserved.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifdef HAVE_CONFIG_H
@@ -37,7 +23,8 @@
 #include <ofono/modem.h>
 #include <ofono/siri.h>
 
-#include "hfpmodem.h"
+#include <drivers/atmodem/atutil.h>
+
 #include "hfp.h"
 #include "slc.h"
 
@@ -196,18 +183,9 @@ static void hfp_siri_set_eyes_free_mode(struct ofono_siri *siri,
 }
 
 static const struct ofono_siri_driver driver = {
-	.name = "hfpmodem",
 	.probe = hfp_siri_probe,
 	.remove = hfp_siri_remove,
 	.set_eyes_free_mode = hfp_siri_set_eyes_free_mode,
 };
 
-void hfp_siri_init(void)
-{
-	ofono_siri_driver_register(&driver);
-}
-
-void hfp_siri_exit(void)
-{
-	ofono_siri_driver_unregister(&driver);
-}
+OFONO_ATOM_DRIVER_BUILTIN(siri, hfpmodem, &driver)
