@@ -1,22 +1,8 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2009-2010  Nokia Corporation and/or its subsidiary(-ies)
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2009-2010  Nokia Corporation and/or its subsidiary(-ies).
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifdef HAVE_CONFIG_H
@@ -38,7 +24,6 @@
 #include <gisi/client.h>
 #include <gisi/iter.h>
 
-#include "isimodem.h"
 #include "isiutil.h"
 #include "gpds.h"
 #include "info.h"
@@ -490,19 +475,10 @@ error:
 }
 
 static const struct ofono_gprs_driver driver = {
-	.name			= "isimodem",
 	.probe			= isi_gprs_probe,
 	.remove			= isi_gprs_remove,
 	.set_attached		= isi_gprs_set_attached,
 	.attached_status	= isi_gprs_attached_status,
 };
 
-void isi_gprs_init(void)
-{
-	ofono_gprs_driver_register(&driver);
-}
-
-void isi_gprs_exit(void)
-{
-	ofono_gprs_driver_unregister(&driver);
-}
+OFONO_ATOM_DRIVER_BUILTIN(gprs, isimodem, &driver)
