@@ -1,30 +1,15 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2011  ST-Ericsson AB
+ * Copyright (C) 2011  Nokia Corporation and/or its subsidiary(-ies)
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2011  ST-Ericsson AB.
- *  Copyright (C) 2011  Nokia Corporation and/or its subsidiary(-ies).
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
-#define _GNU_SOURCE
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -41,7 +26,6 @@
 #include <ofono/sim.h>
 
 #include "simutil.h"
-#include "isimodem.h"
 #include "isiutil.h"
 #include "sim.h"
 #include "uicc.h"
@@ -68,8 +52,6 @@ enum uicc_flag {
 	UICC_FLAG_PASSWD_REQUIRED =	1 << 2,
 };
 
-static GHashTable *g_modems;
-
 struct file_info {
 	int fileid;
 	int length;
@@ -395,6 +377,8 @@ static gboolean send_uicc_read_file_info(GIsiClient *client, uint8_t app_id,
 }
 
 static void uicc_read_file_info(struct ofono_sim *sim, int fileid,
+				const unsigned char *path,
+				unsigned int path_len,
 				ofono_sim_file_info_cb_t cb, void *data)
 {
 	struct uicc_sim_data *sd = ofono_sim_get_data(sim);
@@ -531,6 +515,8 @@ static gboolean send_uicc_read_file_transparent(GIsiClient *client,
 
 static void uicc_read_file_transparent(struct ofono_sim *sim, int fileid,
 					int start, int length,
+					const unsigned char *path,
+					unsigned int path_len,
 					ofono_sim_read_cb_t cb, void *data)
 {
 	struct uicc_sim_data *sd = ofono_sim_get_data(sim);
@@ -653,8 +639,10 @@ static gboolean send_uicc_read_file_linear(GIsiClient *client, uint8_t app_id,
 }
 
 static void uicc_read_file_linear(struct ofono_sim *sim, int fileid, int record,
-					int rec_length, ofono_sim_read_cb_t cb,
-					void *data)
+					int rec_length,
+					const unsigned char *path,
+					unsigned int path_len,
+					ofono_sim_read_cb_t cb,	void *data)
 {
 	struct uicc_sim_data *sd = ofono_sim_get_data(sim);
 	struct isi_cb_data *cbd = isi_cb_data_new(sim, cb, data);
@@ -686,6 +674,8 @@ error:
 
 static void uicc_read_file_cyclic(struct ofono_sim *sim, int fileid,
 					int record, int length,
+					const unsigned char *path,
+					unsigned int path_len,
 					ofono_sim_read_cb_t cb, void *data)
 {
 	DBG("Not implemented");
@@ -695,6 +685,8 @@ static void uicc_read_file_cyclic(struct ofono_sim *sim, int fileid,
 static void uicc_write_file_transparent(struct ofono_sim *sim, int fileid,
 					int start, int length,
 					const unsigned char *value,
+					const unsigned char *path,
+					unsigned int path_len,
 					ofono_sim_write_cb_t cb, void *data)
 {
 	DBG("Not implemented");
@@ -703,14 +695,19 @@ static void uicc_write_file_transparent(struct ofono_sim *sim, int fileid,
 
 static void uicc_write_file_linear(struct ofono_sim *sim, int fileid, int record,
 					int length, const unsigned char *value,
+					const unsigned char *path,
+					unsigned int path_len,
 					ofono_sim_write_cb_t cb, void *data)
 {
 	DBG("Not implemented");
 	CALLBACK_WITH_FAILURE(cb, data);
 }
 
-static void uicc_write_file_cyclic(struct ofono_sim *sim, int fileid, int length,
+static void uicc_write_file_cyclic(struct ofono_sim *sim, int fileid,
+					int length,
 					const unsigned char *value,
+					const unsigned char *path,
+					unsigned int path_len,
 					ofono_sim_write_cb_t cb, void *data)
 {
 	DBG("Not implemented");
@@ -1017,14 +1014,6 @@ static void uicc_lock(struct ofono_sim *sim, enum ofono_sim_password_type type,
 	CALLBACK_WITH_FAILURE(cb, data);
 }
 
-static void uicc_query_locked(struct ofono_sim *sim,
-				enum ofono_sim_password_type type,
-				ofono_sim_locked_cb_t cb, void *data)
-{
-	DBG("Not implemented");
-	CALLBACK_WITH_FAILURE(cb, -1, data);
-}
-
 static gboolean decode_fcp_pin_status(const GIsiSubBlockIter *iter, uint8_t read,
 					uint8_t *pin1, uint8_t *pin2)
 {
@@ -1615,8 +1604,6 @@ static int uicc_sim_probe(struct ofono_sim *sim, unsigned int vendor,
 		return -ENOMEM;
 	}
 
-	g_hash_table_insert(g_modems, g_isi_client_modem(sd->client), sim);
-
 	sd->server_running = FALSE;
 	sd->uicc_app_started = FALSE;
 	sd->pin_state_received = FALSE;
@@ -1637,15 +1624,12 @@ static void uicc_sim_remove(struct ofono_sim *sim)
 	if (data == NULL)
 		return;
 
-	g_hash_table_remove(g_modems, g_isi_client_modem(data->client));
-
 	g_hash_table_destroy(data->app_table);
 	g_isi_client_destroy(data->client);
 	g_free(data);
 }
 
-static struct ofono_sim_driver driver = {
-	.name			= "wgmodem2.5",
+static const struct ofono_sim_driver driver = {
 	.probe			= uicc_sim_probe,
 	.remove			= uicc_sim_remove,
 	.read_file_info		= uicc_read_file_info,
@@ -1662,43 +1646,6 @@ static struct ofono_sim_driver driver = {
 	.reset_passwd		= uicc_reset_passwd,
 	.change_passwd		= uicc_change_passwd,
 	.lock			= uicc_lock,
-	.query_locked		= uicc_query_locked,
 };
 
-void isi_uicc_init(void)
-{
-	g_modems = g_hash_table_new(g_direct_hash, g_direct_equal);
-	ofono_sim_driver_register(&driver);
-}
-
-void isi_uicc_exit(void)
-{
-	g_hash_table_destroy(g_modems);
-	ofono_sim_driver_unregister(&driver);
-}
-
-gboolean isi_uicc_properties(GIsiModem *modem, int *app_id, int *app_type,
-				int *client_id)
-{
-	struct ofono_sim *sim;
-	struct uicc_sim_data *sd;
-
-	sim = g_hash_table_lookup(g_modems, modem);
-	if (sim == NULL)
-		return FALSE;
-
-	sd = ofono_sim_get_data(sim);
-	if (sd == NULL)
-		return FALSE;
-
-	if (app_id != NULL)
-		*app_id = sd->app_id;
-
-	if (app_type != NULL)
-		*app_type = sd->app_type;
-
-	if (client_id != NULL)
-		*client_id = sd->client_id;
-
-	return TRUE;
-}
+OFONO_ATOM_DRIVER_BUILTIN(sim, wgmodem2_5, &driver)
