@@ -1,22 +1,8 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2011-2012  Intel Corporation
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2011-2012  Intel Corporation. All rights reserved.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifdef HAVE_CONFIG_H
@@ -35,8 +21,7 @@
 struct settings_data {
 	struct qmi_service *nas;
 	struct qmi_service *dms;
-	uint16_t major;
-	uint16_t minor;
+	unsigned int rat_mode_any;
 };
 
 static void get_system_selection_pref_cb(struct qmi_result *result,
@@ -114,27 +99,22 @@ static void qmi_set_rat_mode(struct ofono_radio_settings *rs, unsigned int mode,
 {
 	struct settings_data *data = ofono_radio_settings_get_data(rs);
 	struct cb_data *cbd = cb_data_new(cb, user_data);
-	uint16_t pref = QMI_NAS_RAT_MODE_PREF_ANY;
+	uint16_t pref = 0;
 	struct qmi_param *param;
 
 	DBG("");
 
-	switch (mode) {
-	case OFONO_RADIO_ACCESS_MODE_ANY:
-		pref = QMI_NAS_RAT_MODE_PREF_ANY;
-		break;
-	case OFONO_RADIO_ACCESS_MODE_GSM:
-		pref = QMI_NAS_RAT_MODE_PREF_GSM;
-		break;
-	case OFONO_RADIO_ACCESS_MODE_UMTS:
-		pref = QMI_NAS_RAT_MODE_PREF_UMTS;
-		break;
-	case OFONO_RADIO_ACCESS_MODE_LTE:
-		pref = QMI_NAS_RAT_MODE_PREF_LTE;
-		break;
-	case OFONO_RADIO_ACCESS_MODE_LTE|OFONO_RADIO_ACCESS_MODE_GSM:
-		pref = QMI_NAS_RAT_MODE_PREF_LTE|QMI_NAS_RAT_MODE_PREF_GSM;
-		break;
+	if (mode == OFONO_RADIO_ACCESS_MODE_ANY)
+		pref = data->rat_mode_any;
+	else {
+		if (mode & OFONO_RADIO_ACCESS_MODE_GSM)
+			pref |= QMI_NAS_RAT_MODE_PREF_GSM;
+
+		if (mode & OFONO_RADIO_ACCESS_MODE_UMTS)
+			pref |= QMI_NAS_RAT_MODE_PREF_UMTS;
+
+		if (mode & OFONO_RADIO_ACCESS_MODE_LTE)
+			pref |= QMI_NAS_RAT_MODE_PREF_LTE;
 	}
 
 	param = qmi_param_new();
@@ -152,14 +132,42 @@ static void qmi_set_rat_mode(struct ofono_radio_settings *rs, unsigned int mode,
 	l_free(cbd);
 }
 
+static unsigned int _update_available_rats(struct settings_data *rsd,
+					const struct qmi_dms_device_caps *caps)
+{
+	unsigned int available_rats = 0;
+	uint8_t i;
+
+	rsd->rat_mode_any = 0;
+
+	for (i = 0; i < caps->radio_if_count; i++) {
+		switch (caps->radio_if[i]) {
+		case QMI_DMS_RADIO_IF_GSM:
+			available_rats |= OFONO_RADIO_ACCESS_MODE_GSM;
+			rsd->rat_mode_any |= QMI_NAS_RAT_MODE_PREF_GSM;
+			break;
+		case QMI_DMS_RADIO_IF_UMTS:
+			rsd->rat_mode_any |= QMI_NAS_RAT_MODE_PREF_UMTS;
+			available_rats |= OFONO_RADIO_ACCESS_MODE_UMTS;
+			break;
+		case QMI_DMS_RADIO_IF_LTE:
+			available_rats |= OFONO_RADIO_ACCESS_MODE_LTE;
+			rsd->rat_mode_any |= QMI_NAS_RAT_MODE_PREF_LTE;
+			break;
+		}
+	}
+
+	return available_rats;
+}
+
 static void get_caps_cb(struct qmi_result *result, void *user_data)
 {
 	struct cb_data *cbd = user_data;
+	struct ofono_radio_settings *rs = cbd->user;
+	struct settings_data *rsd = ofono_radio_settings_get_data(rs);
 	ofono_radio_settings_available_rats_query_cb_t cb = cbd->cb;
 	const struct qmi_dms_device_caps *caps;
-	unsigned int available_rats;
 	uint16_t len;
-	uint8_t i;
 
 	DBG("");
 
@@ -170,22 +178,7 @@ static void get_caps_cb(struct qmi_result *result, void *user_data)
 	if (!caps)
 		goto error;
 
-	available_rats = 0;
-	for (i = 0; i < caps->radio_if_count; i++) {
-		switch (caps->radio_if[i]) {
-		case QMI_DMS_RADIO_IF_GSM:
-			available_rats |= OFONO_RADIO_ACCESS_MODE_GSM;
-			break;
-		case QMI_DMS_RADIO_IF_UMTS:
-			available_rats |= OFONO_RADIO_ACCESS_MODE_UMTS;
-			break;
-		case QMI_DMS_RADIO_IF_LTE:
-			available_rats |= OFONO_RADIO_ACCESS_MODE_LTE;
-			break;
-		}
-	}
-
-	CALLBACK_WITH_SUCCESS(cb, available_rats, cbd->data);
+	CALLBACK_WITH_SUCCESS(cb, _update_available_rats(rsd, caps), cbd->data);
 
 	return;
 
@@ -203,6 +196,8 @@ static void qmi_query_available_rats(struct ofono_radio_settings *rs,
 	if (!rsd->dms)
 		goto error;
 
+	cbd->user = rs;
+
 	if (qmi_service_send(rsd->dms, QMI_DMS_GET_CAPS, NULL,
 					get_caps_cb, cbd, l_free) > 0)
 		return;
@@ -212,60 +207,54 @@ error:
 	CALLBACK_WITH_FAILURE(cb, -1, data);
 }
 
-static void create_dms_cb(struct qmi_service *service, void *user_data)
+static void get_rat_mode_any_cb(struct qmi_result *result, void *user_data)
 {
 	struct ofono_radio_settings *rs = user_data;
-	struct settings_data *data = ofono_radio_settings_get_data(rs);
+	struct settings_data *rsd = ofono_radio_settings_get_data(rs);
+	const struct qmi_dms_device_caps *caps;
+	uint16_t len;
 
 	DBG("");
 
-	if (!service)
-		return;
+	if (qmi_result_set_error(result, NULL))
+		goto error;
 
-	data->dms = service;
-}
-
-static void create_nas_cb(struct qmi_service *service, void *user_data)
-{
-	struct ofono_radio_settings *rs = user_data;
-	struct settings_data *data = ofono_radio_settings_get_data(rs);
-
-	DBG("");
-
-	if (!service) {
-		ofono_error("Failed to request NAS service");
-		ofono_radio_settings_remove(rs);
-		return;
-	}
-
-	if (!qmi_service_get_version(service, &data->major, &data->minor)) {
-		ofono_error("Failed to get NAS service version");
-		ofono_radio_settings_remove(rs);
-		return;
-	}
-
-	data->nas = service;
+	caps = qmi_result_get(result, QMI_DMS_RESULT_DEVICE_CAPS, &len);
+	if (!caps)
+		goto error;
 
+	_update_available_rats(rsd, caps);
 	ofono_radio_settings_register(rs);
+
+	return;
+
+error:
+	ofono_error("Failed to get RAT modes");
+	ofono_radio_settings_remove(rs);
 }
 
-static int qmi_radio_settings_probe(struct ofono_radio_settings *rs,
-					unsigned int vendor, void *user_data)
+static int qmi_radio_settings_probev(struct ofono_radio_settings *rs,
+					unsigned int vendor, va_list args)
 {
-	struct qmi_device *device = user_data;
+	struct qmi_service *dms = va_arg(args, struct qmi_service *);
+	struct qmi_service *nas = va_arg(args, struct qmi_service *);
 	struct settings_data *data;
 
 	DBG("");
 
+	if (!qmi_service_send(dms, QMI_DMS_GET_CAPS, NULL,
+					get_rat_mode_any_cb, rs, NULL)) {
+		qmi_service_free(dms);
+		qmi_service_free(nas);
+		return -EIO;
+	}
+
 	data = l_new(struct settings_data, 1);
+	data->dms = dms;
+	data->nas = nas;
 
 	ofono_radio_settings_set_data(rs, data);
 
-	qmi_service_create_shared(device, QMI_SERVICE_DMS,
-						create_dms_cb, rs, NULL);
-	qmi_service_create_shared(device, QMI_SERVICE_NAS,
-						create_nas_cb, rs, NULL);
-
 	return 0;
 }
 
@@ -284,7 +273,7 @@ static void qmi_radio_settings_remove(struct ofono_radio_settings *rs)
 }
 
 static const struct ofono_radio_settings_driver driver = {
-	.probe		= qmi_radio_settings_probe,
+	.probev		= qmi_radio_settings_probev,
 	.remove		= qmi_radio_settings_remove,
 	.set_rat_mode	= qmi_set_rat_mode,
 	.query_rat_mode = qmi_query_rat_mode,
