@@ -349,7 +349,7 @@ static void delete_msg(struct ofono_sms *sms, uint8_t tag)
 	param = qmi_param_new();
 
 	qmi_param_append_uint8(param, QMI_WMS_PARAM_DEL_STORE,
-				QMI_WMS_STORAGE_TYPE_NV);
+				QMI_WMS_STORAGE_TYPE_UIM);
 
 	if (tag == QMI_WMS_MT_UNDEFINE) {
 		DBG("delete read msg type %d ndx %d", data->rd_msg_id.type,
@@ -516,7 +516,7 @@ static void get_msg_list(struct ofono_sms *sms)
 
 	/* query NOT_READ msg list */
 	qmi_param_append_uint8(param, QMI_WMS_PARAM_STORAGE_TYPE,
-				QMI_WMS_STORAGE_TYPE_NV);
+				QMI_WMS_STORAGE_TYPE_UIM);
 	qmi_param_append_uint8(param, QMI_WMS_PARAM_TAG_TYPE,
 				QMI_WMS_MT_NOT_READ);
 	qmi_param_append_uint8(param, QMI_WMS_PARAM_MESSAGE_MODE,
@@ -571,6 +571,47 @@ static void get_msg_protocol(struct ofono_sms *sms)
 				get_msg_protocol_cb, sms, NULL);
 }
 
+static void send_ack_cb(struct qmi_result *result, void *user_data)
+{
+	uint16_t err;
+
+	DBG("");
+
+	if (!qmi_result_set_error(result, &err))
+		return;
+
+	DBG("Err: protocol %d - %s",
+			err, qmi_result_get_error(result));
+}
+
+static void send_ack(struct sms_data *data,
+				const struct qmi_wms_result_message *message)
+{
+	struct __attribute__((__packed__)) {
+		uint32_t transaction_id;
+		uint8_t mode;
+		uint8_t success;
+	} ack;
+	struct qmi_param *param;
+
+	ack.transaction_id = message->transaction_id;
+	ack.success = 1;
+
+	if (message->msg_format == 0)
+		ack.mode = QMI_WMS_MESSAGE_MODE_CDMA;
+	else
+		ack.mode = QMI_WMS_MESSAGE_MODE_GSMWCDMA;
+
+	param = qmi_param_new();
+	qmi_param_append(param, 0x01, sizeof(ack), &ack);
+
+	if (qmi_service_send(data->wms, QMI_WMS_SEND_ACK, param,
+				send_ack_cb, NULL, NULL) > 0)
+		return;
+
+	qmi_param_free(param);
+}
+
 static void event_notify(struct qmi_result *result, void *user_data)
 {
 	struct ofono_sms *sms = user_data;
@@ -615,6 +656,9 @@ static void event_notify(struct qmi_result *result, void *user_data)
 			DBG("msg format %d PDU length %d",
 				message->msg_format, plen);
 
+			if (message->ack_required == QMI_WMS_ACK_REQUIRED)
+				send_ack(data, message);
+
 			ofono_sms_deliver_notify(sms, message->msg_data,
 							plen, plen);
 		}
@@ -689,7 +733,7 @@ static void get_routes_cb(struct qmi_result *result, void *user_data)
 	new_list->count = L_CPU_TO_LE16(1);
 	new_list->route[0].msg_type = QMI_WMS_MSG_TYPE_P2P;
 	new_list->route[0].msg_class = QMI_WMS_MSG_CLASS_NONE;
-	new_list->route[0].storage_type = QMI_WMS_STORAGE_TYPE_NV;
+	new_list->route[0].storage_type = QMI_WMS_STORAGE_TYPE_UIM;
 	new_list->route[0].action = QMI_WMS_ACTION_STORE_AND_NOTIFY;
 
 	param = qmi_param_new();
