@@ -1,25 +1,11 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2008-2011  Intel Corporation
+ * Copyright (C) 2010  ST-Ericsson AB
+ * Copyright (C) 2013 Canonical Ltd
+ * Copyright (C) 2013 Jolla Ltd
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2008-2011  Intel Corporation. All rights reserved.
- *  Copyright (C) 2010  ST-Ericsson AB.
- *  Copyright (C) 2013 Canonical Ltd.
- *  Copyright (C) 2013 Jolla Ltd.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifdef HAVE_CONFIG_H
@@ -42,7 +28,7 @@
 #include <gril/grilutil.h>
 
 #include "common.h"
-#include "rilmodem.h"
+#include "rilutil.h"
 
 /* Time between get data status retries */
 #define GET_STATUS_TIMER_MS 5000
@@ -515,19 +501,10 @@ static void ril_gprs_remove(struct ofono_gprs *gprs)
 }
 
 static const struct ofono_gprs_driver driver = {
-	.name			= RILMODEM,
 	.probe			= ril_gprs_probe,
 	.remove			= ril_gprs_remove,
 	.set_attached		= ril_gprs_set_attached,
 	.attached_status	= ril_gprs_registration_status,
 };
 
-void ril_gprs_init(void)
-{
-	ofono_gprs_driver_register(&driver);
-}
-
-void ril_gprs_exit(void)
-{
-	ofono_gprs_driver_unregister(&driver);
-}
+OFONO_ATOM_DRIVER_BUILTIN(gprs, rilmodem, &driver)
