@@ -1,24 +1,10 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2008-2011  Intel Corporation
+ * Copyright (C) 2012-2013 Canonical Ltd
+ * Copyright (C) 2013 Jolla Ltd
  *
- *  oFono - Open Source Telephony - RIL Modem Support
- *
- *  Copyright (C) 2008-2011  Intel Corporation. All rights reserved.
- *  Copyright (C) 2012-2013 Canonical Ltd.
- *  Copyright (C) 2013 Jolla Ltd.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifdef HAVE_CONFIG_H
@@ -41,8 +27,7 @@
 #include "smsutil.h"
 #include "util.h"
 #include "common.h"
-
-#include "rilmodem.h"
+#include "rilutil.h"
 
 struct sms_data {
 	GRil *ril;
@@ -503,7 +488,6 @@ static void ril_sms_remove(struct ofono_sms *sms)
 }
 
 static const struct ofono_sms_driver driver = {
-	.name		= RILMODEM,
 	.probe		= ril_sms_probe,
 	.sca_query	= ril_csca_query,
 	.sca_set	= ril_csca_set,
@@ -513,12 +497,4 @@ static const struct ofono_sms_driver driver = {
 	.bearer_set	= ril_sms_bearer_set
 };
 
-void ril_sms_init(void)
-{
-	ofono_sms_driver_register(&driver);
-}
-
-void ril_sms_exit(void)
-{
-	ofono_sms_driver_unregister(&driver);
-}
+OFONO_ATOM_DRIVER_BUILTIN(sms, rilmodem, &driver)
