@@ -1,24 +1,10 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2008-2011  Intel Corporation
+ * Copyright (C) 2012-2013 Canonical Ltd
+ * Copyright (C) 2013 Jolla Ltd
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2008-2011  Intel Corporation. All rights reserved.
- *  Copyright (C) 2012-2013 Canonical Ltd.
- *  Copyright (C) 2013 Jolla Ltd.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifdef HAVE_CONFIG_H
@@ -41,7 +27,7 @@
 #include <gril/gril.h>
 
 #include "common.h"
-#include "rilmodem.h"
+#include "rilutil.h"
 #include "voicecall.h"
 
 /* Amount of ms we wait between CLCC calls */
@@ -866,7 +852,6 @@ void ril_voicecall_remove(struct ofono_voicecall *vc)
 }
 
 static const struct ofono_voicecall_driver driver = {
-	.name			= RILMODEM,
 	.probe			= ril_voicecall_probe,
 	.remove			= ril_voicecall_remove,
 	.dial			= ril_dial,
@@ -883,12 +868,4 @@ static const struct ofono_voicecall_driver driver = {
 	.release_all_active	= ril_release_all_active,
 };
 
-void ril_voicecall_init(void)
-{
-	ofono_voicecall_driver_register(&driver);
-}
-
-void ril_voicecall_exit(void)
-{
-	ofono_voicecall_driver_unregister(&driver);
-}
+OFONO_ATOM_DRIVER_BUILTIN(voicecall, rilmodem, &driver)
