@@ -1,22 +1,8 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2016  Endocode AG
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2016  Endocode AG. All rights reserved.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifdef HAVE_CONFIG_H
@@ -120,25 +106,3 @@ int ublox_is_toby_l4(const struct ublox_model *model)
 {
 	return model->flags & UBLOX_F_TOBY_L4;
 }
-
-static int ubloxmodem_init(void)
-{
-	ublox_gprs_context_init();
-	ublox_netreg_init();
-	ublox_netmon_init();
-	ublox_lte_init();
-
-	return 0;
-}
-
-static void ubloxmodem_exit(void)
-{
-	ublox_gprs_context_exit();
-	ublox_netreg_exit();
-	ublox_netmon_exit();
-	ublox_lte_exit();
-}
-
-OFONO_PLUGIN_DEFINE(ubloxmodem, "U-Blox Toby L2 high speed modem driver",
-			VERSION, OFONO_PLUGIN_PRIORITY_DEFAULT,
-			ubloxmodem_init, ubloxmodem_exit)
