@@ -1,22 +1,8 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2017  Intel Corporation
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2017  Intel Corporation. All rights reserved.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifdef HAVE_CONFIG_H
@@ -34,11 +20,11 @@
 #include <ofono/log.h>
 #include <ofono/ims.h>
 
+#include <drivers/atmodem/atutil.h>
+
 #include "gatchat.h"
 #include "gatresult.h"
 
-#include "xmm7modem.h"
-
 static const char *none_prefix[] = { NULL };
 static const char *cireg_prefix[] = { "+CIREG:", NULL };
 
@@ -200,7 +186,7 @@ static void cireg_support_cb(gboolean ok, GAtResult *result,
 				xmm_cireg_set_cb, ims, NULL);
 }
 
-static int xmm_ims_probe(struct ofono_ims *ims, void *data)
+static int xmm_ims_probe(struct ofono_ims *ims, unsigned int vendor, void *data)
 {
 	GAtChat *chat = data;
 	struct ims_driver_data *idd;
@@ -235,7 +221,6 @@ static void xmm_ims_remove(struct ofono_ims *ims)
 }
 
 static const struct ofono_ims_driver driver = {
-	.name				= "xmm7modem",
 	.probe				= xmm_ims_probe,
 	.remove				= xmm_ims_remove,
 	.ims_register			= xmm_ims_register,
@@ -243,12 +228,4 @@ static const struct ofono_ims_driver driver = {
 	.registration_status		= xmm_ims_registration_status,
 };
 
-void xmm_ims_init(void)
-{
-	ofono_ims_driver_register(&driver);
-}
-
-void xmm_ims_exit(void)
-{
-	ofono_ims_driver_unregister(&driver);
-}
+OFONO_ATOM_DRIVER_BUILTIN(ims, xmm7modem, &driver)
