@@ -1,23 +1,9 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2016  Endocode AG
+ * Copyright (C) 2018 Gemalto M2M
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2016  Endocode AG. All rights reserved.
- *  Copyright (C) 2018 Gemalto M2M
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifndef __OFONO_LTE_H
@@ -27,6 +13,8 @@
 extern "C" {
 #endif
 
+#include <stdarg.h>
+
 #include <ofono/types.h>
 
 struct ofono_lte;
@@ -42,21 +30,18 @@ struct ofono_lte_default_attach_info {
 typedef void (*ofono_lte_cb_t)(const struct ofono_error *error, void *data);
 
 struct ofono_lte_driver {
-	const char *name;
+	unsigned int flags;
 	int (*probe)(struct ofono_lte *lte, unsigned int vendor, void *data);
+	int (*probev)(struct ofono_lte *lte, unsigned int vendor, va_list args);
 	void (*remove)(struct ofono_lte *lte);
 	void (*set_default_attach_info)(const struct ofono_lte *lte,
 			const struct ofono_lte_default_attach_info *info,
 			ofono_lte_cb_t cb, void *data);
 };
 
-int ofono_lte_driver_register(const struct ofono_lte_driver *d);
-
-void ofono_lte_driver_unregister(const struct ofono_lte_driver *d);
-
 struct ofono_lte *ofono_lte_create(struct ofono_modem *modem,
 					unsigned int vendor,
-					const char *driver, void *data);
+					const char *driver, ...);
 
 void ofono_lte_register(struct ofono_lte *lte);
 
