@@ -1,22 +1,8 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2008-2011  Intel Corporation
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2008-2011  Intel Corporation. All rights reserved.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifndef __OFONO_NETREG_H
@@ -26,6 +12,8 @@
 extern "C" {
 #endif
 
+#include <stdarg.h>
+
 #include <ofono/types.h>
 
 struct ofono_netreg;
@@ -69,9 +57,11 @@ typedef void (*ofono_netreg_strength_cb_t)(const struct ofono_error *error,
  * vendor extensions for signal strength notification.
  */
 struct ofono_netreg_driver {
-	const char *name;
+	unsigned int flags;
 	int (*probe)(struct ofono_netreg *netreg, unsigned int vendor,
 			void *data);
+	int (*probev)(struct ofono_netreg *netreg, unsigned int vendor,
+			va_list args);
 	void (*remove)(struct ofono_netreg *netreg);
 	void (*registration_status)(struct ofono_netreg *netreg,
 			ofono_netreg_status_cb_t cb, void *data);
@@ -94,13 +84,9 @@ void ofono_netreg_status_notify(struct ofono_netreg *netreg, int status,
 void ofono_netreg_time_notify(struct ofono_netreg *netreg,
 				struct ofono_network_time *info);
 
-int ofono_netreg_driver_register(const struct ofono_netreg_driver *d);
-void ofono_netreg_driver_unregister(const struct ofono_netreg_driver *d);
-
 struct ofono_netreg *ofono_netreg_create(struct ofono_modem *modem,
 						unsigned int vendor,
-						const char *driver,
-						void *data);
+						const char *driver, ...);
 
 void ofono_netreg_register(struct ofono_netreg *netreg);
 void ofono_netreg_remove(struct ofono_netreg *netreg);
