@@ -1,22 +1,8 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2013  Intel Corporation
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2013  Intel Corporation. All rights reserved.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifdef HAVE_CONFIG_H
@@ -241,13 +227,5 @@ void bt_connect_profile(DBusConnection *conn,
 							cb, user_data);
 }
 
-void bt_disconnect_profile(DBusConnection *conn,
-				const char *device, const char *uuid,
-				bt_finish_cb cb, gpointer user_data)
-{
-	device_send_message(conn, device, "DisconnectProfile", uuid,
-							cb, user_data);
-}
-
 OFONO_PLUGIN_DEFINE(bluez5, "BlueZ 5 Utils Plugin", VERSION,
 			OFONO_PLUGIN_PRIORITY_DEFAULT, NULL, NULL)
