@@ -1,23 +1,9 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2008-2011  Intel Corporation
+ * Copyright (C) 2010  ST-Ericsson AB
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2008-2011  Intel Corporation. All rights reserved.
- *  Copyright (C) 2010  ST-Ericsson AB.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifdef HAVE_CONFIG_H
@@ -313,6 +299,15 @@ static void esimsr_notify(GAtResult *result, gpointer user_data)
 	handle_sim_status(status, modem);
 }
 
+static void epev_notify(GAtResult *result, gpointer user_data)
+{
+	struct ofono_modem *modem = user_data;
+	struct ofono_sim *sim = ofono_modem_get_sim(modem);
+
+	if (sim)
+		ofono_sim_initialized_notify(sim);
+}
+
 static int ste_enable(struct ofono_modem *modem)
 {
 	struct ste_data *data = ofono_modem_get_data(modem);
@@ -353,6 +348,9 @@ static int ste_enable(struct ofono_modem *modem)
 	g_at_chat_register(data->chat[AT_SIM], "*ESIMSR:", esimsr_notify,
 				FALSE, modem, NULL);
 
+	g_at_chat_send(data->chat[AT_SIM], "AT*EPEE=1", NULL, NULL, NULL, NULL);
+	g_at_chat_register(data->chat[AT_SIM], "*EPEV", epev_notify,
+					FALSE, modem, NULL);
 	return -EINPROGRESS;
 
 error:
@@ -423,9 +421,8 @@ static void ste_set_online(struct ofono_modem *modem, ofono_bool_t online,
 	if (g_at_chat_send(chat, command, NULL, set_online_cb, cbd, g_free))
 		return;
 
-	g_free(cbd);
-
 	CALLBACK_WITH_FAILURE(cb, cbd->data);
+	g_free(cbd);
 }
 
 static void ste_pre_sim(struct ofono_modem *modem)
@@ -496,7 +493,6 @@ static void ste_post_online(struct ofono_modem *modem)
 }
 
 static struct ofono_modem_driver ste_driver = {
-	.name		= "ste",
 	.probe		= ste_probe,
 	.remove		= ste_remove,
 	.enable		= ste_enable,
@@ -507,15 +503,4 @@ static struct ofono_modem_driver ste_driver = {
 	.post_online	= ste_post_online,
 };
 
-static int ste_init(void)
-{
-	return ofono_modem_driver_register(&ste_driver);
-}
-
-static void ste_exit(void)
-{
-	ofono_modem_driver_unregister(&ste_driver);
-}
-
-OFONO_PLUGIN_DEFINE(ste, "ST-Ericsson modem driver", VERSION,
-			OFONO_PLUGIN_PRIORITY_DEFAULT, ste_init, ste_exit)
+OFONO_MODEM_DRIVER_BUILTIN(ste, &ste_driver)
