@@ -1,22 +1,8 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2008-2011  Intel Corporation
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2008-2011  Intel Corporation. All rights reserved.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifdef HAVE_CONFIG_H
@@ -27,7 +13,6 @@
 #include <string.h>
 #include <errno.h>
 
-#include <glib.h>
 #include <ell/ell.h>
 
 #include <ofono/types.h>
@@ -237,23 +222,27 @@ struct error_entry ceer_errors[] = {
 	{ 127,	"Interworking, unspecified" },
 };
 
-gboolean valid_number_format(const char *number, int length)
+bool valid_number_format(const char *number, size_t length)
 {
-	int len = strlen(number);
-	int begin = 0;
-	int i;
+	size_t len;
+	size_t begin = 0;
+	size_t i;
 
+	if (!number)
+		return false;
+
+	len = strlen(number);
 	if (!len)
-		return FALSE;
+		return false;
 
 	if (number[0] == '+')
 		begin = 1;
 
 	if (begin == len)
-		return FALSE;
+		return false;
 
 	if ((len - begin) > length)
-		return FALSE;
+		return false;
 
 	for (i = begin; i < len; i++) {
 		if (number[i] >= '0' && number[i] <= '9')
@@ -262,10 +251,10 @@ gboolean valid_number_format(const char *number, int length)
 		if (number[i] == '*' || number[i] == '#')
 			continue;
 
-		return FALSE;
+		return false;
 	}
 
-	return TRUE;
+	return true;
 }
 
 /*
@@ -274,12 +263,12 @@ gboolean valid_number_format(const char *number, int length)
  * Destination address, or EFADN (Abbreviated dialling numbers),
  * are up 20 digits.
  */
-gboolean valid_phone_number_format(const char *number)
+bool valid_phone_number_format(const char *number)
 {
 	return valid_number_format(number, 20);
 }
 
-gboolean valid_long_phone_number_format(const char *number)
+bool valid_long_phone_number_format(const char *number)
 {
 	return valid_number_format(number, OFONO_MAX_PHONE_NUMBER_LENGTH);
 }
@@ -416,17 +405,26 @@ const char *phone_number_to_string(const struct ofono_phone_number *ph)
 	return buffer;
 }
 
-void string_to_phone_number(const char *str, struct ofono_phone_number *ph)
+void __string_to_phone_number(const char *str, struct ofono_phone_number *ph)
 {
 	if (str[0] == '+') {
-		strcpy(ph->number, str+1);
+		l_strlcpy(ph->number, str + 1, sizeof(ph->number));
 		ph->type = 145;	/* International */
 	} else {
-		strcpy(ph->number, str);
+		l_strlcpy(ph->number, str, sizeof(ph->number));
 		ph->type = 129;	/* Local */
 	}
 }
 
+int string_to_phone_number(const char *str, struct ofono_phone_number *ph)
+{
+	if (!valid_phone_number_format(str))
+		return -EINVAL;
+
+	__string_to_phone_number(str, ph);
+	return 0;
+}
+
 gboolean valid_ussd_string(const char *str, gboolean call_in_progress)
 {
 	int len = strlen(str);
@@ -561,7 +559,7 @@ gboolean parse_ss_control_string(char *str, int *ss_type,
 		goto out;
 
 	for (i = 0; i < strlen(*sc); i++)
-		if (!g_ascii_isdigit((*sc)[i]))
+		if (!l_ascii_isdigit((*sc)[i]))
 			goto out;
 
 	NEXT_FIELD(c, *sia);
@@ -609,7 +607,7 @@ const char *bearer_class_to_string(enum bearer_class cls)
 	case BEARER_CLASS_DEFAULT:
 	case BEARER_CLASS_SS_DEFAULT:
 		break;
-	};
+	}
 
 	return NULL;
 }
@@ -681,7 +679,7 @@ gboolean is_valid_apn(const char *apn)
 		return FALSE;
 
 	for (i = 0; apn[i] != '\0'; i++) {
-		if (g_ascii_isalnum(apn[i]))
+		if (l_ascii_isalnum(apn[i]))
 			continue;
 
 		if (apn[i] == '-')
@@ -743,7 +741,7 @@ const char *gprs_proto_to_string(enum ofono_gprs_proto proto)
 		return "ipv6";
 	case OFONO_GPRS_PROTO_IPV4V6:
 		return "dual";
-	};
+	}
 
 	return NULL;
 }
@@ -756,7 +754,7 @@ bool gprs_proto_from_string(const char *str, enum ofono_gprs_proto *proto)
 	} else if (l_streq0(str, "ipv6")) {
 		*proto = OFONO_GPRS_PROTO_IPV6;
 		return true;
-	} else if (g_str_equal(str, "dual")) {
+	} else if (l_streq0(str, "dual")) {
 		*proto = OFONO_GPRS_PROTO_IPV4V6;
 		return true;
 	}
@@ -773,7 +771,7 @@ const char *gprs_auth_method_to_string(enum ofono_gprs_auth_method auth)
 		return "pap";
 	case OFONO_GPRS_AUTH_METHOD_NONE:
 		return "none";
-	};
+	}
 
 	return NULL;
 }
