@@ -1,24 +1,11 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2008-2011  Intel Corporation
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2008-2011  Intel Corporation. All rights reserved.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
+#include <stdarg.h>
 #include <glib.h>
 #include <ell/ell.h>
 
@@ -245,15 +232,17 @@ extern struct ofono_driver_desc __stop___ ## type[];			\
 struct ofono_ ## type *ofono_ ## type ##_create(			\
 				struct ofono_modem *modem,		\
 				unsigned int vendor, const char *driver,\
-				void *data)				\
+				...)					\
 {									\
 	const struct ofono_ ## type ## _driver *drv =			\
 		__ofono_driver_builtin_find(driver,			\
 				__start___ ## type,			\
 				__stop___ ## type);			\
+	va_list args;							\
 	struct ofono_ ## type *atom;					\
+	int r;								\
 									\
-	if (!drv || !drv->probe)					\
+	if (!drv || (!drv->probe && !drv->probev))			\
 		return NULL;						\
 									\
 	atom = g_new0(struct ofono_ ##type, 1);				\
@@ -261,12 +250,24 @@ struct ofono_ ## type *ofono_ ## type ##_create(			\
 				type ##_remove, atom);			\
 	__VA_ARGS__							\
 									\
-	if (drv->probe(atom, vendor, data) < 0)	{			\
+	va_start(args, driver);						\
+	if (drv->probev)						\
+		r = drv->probev(atom, vendor, args);			\
+	else								\
+		r = drv->probe(atom, vendor, va_arg(args, void *));	\
+	va_end(args);							\
+									\
+	if (r < 0) {							\
 		ofono_ ## type ##_remove(atom);				\
 		return NULL;						\
 	}								\
 									\
 	atom->driver = drv;						\
+									\
+	if (atom->driver->flags &					\
+			OFONO_ATOM_DRIVER_FLAG_REGISTER_ON_PROBE)	\
+		ofono_ ## type ##_register(atom);			\
+									\
 	return atom;							\
 }
 
